@@ -7,7 +7,7 @@
 #             ANY CHANGE MADE HERE WILL BE LOST !
 #
 ####################################################################
-package XDR::Parse v0.1.2;
+package XDR::Parse v0.1.3;
 use vars qw ( @ISA );
 use strict;
 
@@ -29,106 +29,106 @@ sub new {
 [
 	{#State 0
 		ACTIONS => {
-			"typedef" => 10,
-			"union" => 12,
-			'PASSTHROUGH' => 11,
-			"enum" => 2,
-			"const" => 1,
-			'PREPROC' => 8,
-			"struct" => 3
+			"union" => 10,
+			'PASSTHROUGH' => 9,
+			"enum" => 7,
+			'PREPROC' => 11,
+			"const" => 3,
+			"struct" => 5,
+			"typedef" => 4
 		},
 		GOTOS => {
-			'specification' => 9,
-			'typeDef' => 5,
-			'constantDef' => 6,
-			'definitions' => 7,
-			'definition' => 4
+			'specification' => 12,
+			'definition' => 6,
+			'definitions' => 8,
+			'constantDef' => 2,
+			'typeDef' => 1
 		}
 	},
 	{#State 1
+		DEFAULT => -7
+	},
+	{#State 2
+		DEFAULT => -8
+	},
+	{#State 3
 		ACTIONS => {
 			'IDENT' => 13
 		}
 	},
-	{#State 2
-		ACTIONS => {
-			'IDENT' => 14
-		}
-	},
-	{#State 3
-		ACTIONS => {
-			'IDENT' => 15
-		}
-	},
 	{#State 4
 		ACTIONS => {
-			"const" => 1,
-			'PREPROC' => 8,
-			"enum" => 2,
-			"struct" => 3,
-			"typedef" => 10,
-			"union" => 12,
-			'PASSTHROUGH' => 11
+			"union" => 14,
+			"long" => 15,
+			"bool" => 16,
+			"string" => 17,
+			"quadruple" => 20,
+			"int" => 19,
+			"unsigned" => 21,
+			"hyper" => 22,
+			"opaque" => 23,
+			"enum" => 24,
+			"double" => 25,
+			"short" => 27,
+			'IDENT' => 28,
+			"struct" => 29,
+			"float" => 30,
+			"char" => 32,
+			"void" => 31
 		},
-		DEFAULT => -3,
 		GOTOS => {
-			'definition' => 4,
-			'typeDef' => 5,
-			'constantDef' => 6,
-			'definitions' => 16
+			'declaration' => 18,
+			'typeSpecifier' => 26
 		}
 	},
 	{#State 5
-		DEFAULT => -7
+		ACTIONS => {
+			'IDENT' => 33
+		}
 	},
 	{#State 6
-		DEFAULT => -8
+		ACTIONS => {
+			"const" => 3,
+			"typedef" => 4,
+			"struct" => 5,
+			"union" => 10,
+			'PASSTHROUGH' => 9,
+			"enum" => 7,
+			'PREPROC' => 11
+		},
+		DEFAULT => -3,
+		GOTOS => {
+			'constantDef' => 2,
+			'typeDef' => 1,
+			'definitions' => 34,
+			'definition' => 6
+		}
 	},
 	{#State 7
 		ACTIONS => {
-			'TRAILING_COMMENT' => 17
+			'IDENT' => 35
+		}
+	},
+	{#State 8
+		ACTIONS => {
+			'TRAILING_COMMENT' => 36
 		},
 		DEFAULT => -1
 	},
-	{#State 8
-		DEFAULT => -6
-	},
 	{#State 9
-		ACTIONS => {
-			'' => 18
-		}
+		DEFAULT => -5
 	},
 	{#State 10
 		ACTIONS => {
-			"float" => 24,
-			"int" => 25,
-			"short" => 26,
-			"void" => 21,
-			"hyper" => 23,
-			"enum" => 22,
-			"char" => 19,
-			"struct" => 20,
-			"long" => 34,
-			"opaque" => 35,
-			'IDENT' => 37,
-			"unsigned" => 36,
-			"bool" => 33,
-			"union" => 32,
-			"string" => 29,
-			"double" => 28,
-			"quadruple" => 30
-		},
-		GOTOS => {
-			'typeSpecifier' => 31,
-			'declaration' => 27
+			'IDENT' => 37
 		}
 	},
 	{#State 11
-		DEFAULT => -5
+		DEFAULT => -6
 	},
 	{#State 12
 		ACTIONS => {
-			'IDENT' => 38
+			'' => 38
 		}
 	},
 	{#State 13
@@ -138,230 +138,230 @@ sub new {
 	},
 	{#State 14
 		ACTIONS => {
-			"{" => 40
+			"switch" => 40
 		},
 		GOTOS => {
-			'enumBody' => 41
+			'switch' => 41
 		}
 	},
 	{#State 15
-		ACTIONS => {
-			"{" => 42
-		},
-		GOTOS => {
-			'structBody' => 43
-		}
+		DEFAULT => -36
 	},
 	{#State 16
-		DEFAULT => -4
+		DEFAULT => -43
 	},
 	{#State 17
-		DEFAULT => -2
+		ACTIONS => {
+			'IDENT' => 42
+		}
 	},
 	{#State 18
-		DEFAULT => 0
+		ACTIONS => {
+			";" => 43
+		}
 	},
 	{#State 19
-		DEFAULT => -32
-	},
-	{#State 20
-		ACTIONS => {
-			"{" => 42
-		},
-		GOTOS => {
-			'structBody' => 44
-		}
-	},
-	{#State 21
-		DEFAULT => -60
-	},
-	{#State 22
-		ACTIONS => {
-			"{" => 40
-		},
-		GOTOS => {
-			'enumBody' => 45
-		}
-	},
-	{#State 23
-		DEFAULT => -38
-	},
-	{#State 24
-		DEFAULT => -40
-	},
-	{#State 25
 		DEFAULT => -30
 	},
-	{#State 26
-		DEFAULT => -34
+	{#State 20
+		DEFAULT => -42
 	},
-	{#State 27
+	{#State 21
 		ACTIONS => {
-			";" => 46
+			"char" => 46,
+			"int" => 48,
+			"short" => 45,
+			"hyper" => 44,
+			"long" => 47
 		}
 	},
-	{#State 28
+	{#State 22
+		DEFAULT => -38
+	},
+	{#State 23
+		ACTIONS => {
+			'IDENT' => 49
+		}
+	},
+	{#State 24
+		ACTIONS => {
+			"{" => 51
+		},
+		GOTOS => {
+			'enumBody' => 50
+		}
+	},
+	{#State 25
 		DEFAULT => -41
 	},
+	{#State 26
+		ACTIONS => {
+			'IDENT' => 52,
+			"*" => 53
+		}
+	},
+	{#State 27
+		DEFAULT => -34
+	},
+	{#State 28
+		DEFAULT => -47
+	},
 	{#State 29
 		ACTIONS => {
-			'IDENT' => 47
+			"{" => 54
+		},
+		GOTOS => {
+			'structBody' => 55
 		}
 	},
 	{#State 30
-		DEFAULT => -42
+		DEFAULT => -40
 	},
 	{#State 31
-		ACTIONS => {
-			"*" => 49,
-			'IDENT' => 48
-		}
+		DEFAULT => -60
 	},
 	{#State 32
-		ACTIONS => {
-			"switch" => 51
-		},
-		GOTOS => {
-			'switch' => 50
-		}
+		DEFAULT => -32
 	},
 	{#State 33
-		DEFAULT => -43
+		ACTIONS => {
+			"{" => 54
+		},
+		GOTOS => {
+			'structBody' => 56
+		}
 	},
 	{#State 34
-		DEFAULT => -36
+		DEFAULT => -4
 	},
 	{#State 35
 		ACTIONS => {
-			'IDENT' => 52
+			"{" => 51
+		},
+		GOTOS => {
+			'enumBody' => 57
 		}
 	},
 	{#State 36
-		ACTIONS => {
-			"hyper" => 56,
-			"long" => 53,
-			"short" => 55,
-			"char" => 57,
-			"int" => 54
-		}
+		DEFAULT => -2
 	},
 	{#State 37
-		DEFAULT => -47
-	},
-	{#State 38
 		ACTIONS => {
-			"switch" => 51
+			"switch" => 40
 		},
 		GOTOS => {
 			'switch' => 58
 		}
 	},
+	{#State 38
+		DEFAULT => 0
+	},
 	{#State 39
 		ACTIONS => {
-			'CONST' => 60,
-			'IDENT' => 59
+			'CONST' => 59,
+			'IDENT' => 60
 		}
 	},
 	{#State 40
 		ACTIONS => {
-			'IDENT' => 61
-		},
-		GOTOS => {
-			'enumItems' => 62,
-			'enumItem' => 63
+			"(" => 61
 		}
 	},
 	{#State 41
-		ACTIONS => {
-			";" => 64
-		}
+		DEFAULT => -46
 	},
 	{#State 42
 		ACTIONS => {
-			"quadruple" => 30,
-			"string" => 29,
-			"double" => 28,
-			"union" => 32,
-			"bool" => 33,
-			"unsigned" => 36,
-			'IDENT' => 37,
-			"opaque" => 35,
-			"long" => 34,
-			"struct" => 20,
-			"char" => 19,
-			"hyper" => 23,
-			"enum" => 22,
-			"void" => 21,
-			"short" => 26,
-			"int" => 25,
-			"float" => 24
-		},
-		GOTOS => {
-			'structItems' => 66,
-			'declaration' => 65,
-			'structItem' => 67,
-			'typeSpecifier' => 31
+			"<" => 62
 		}
 	},
 	{#State 43
-		ACTIONS => {
-			";" => 68
-		}
-	},
-	{#State 44
-		DEFAULT => -45
-	},
-	{#State 45
-		DEFAULT => -44
-	},
-	{#State 46
 		DEFAULT => -9
 	},
+	{#State 44
+		DEFAULT => -39
+	},
+	{#State 45
+		DEFAULT => -35
+	},
+	{#State 46
+		DEFAULT => -33
+	},
 	{#State 47
-		ACTIONS => {
-			"<" => 69
-		}
+		DEFAULT => -37
 	},
 	{#State 48
-		ACTIONS => {
-			"<" => 70,
-			"[" => 71
-		},
-		DEFAULT => -50
+		DEFAULT => -31
 	},
 	{#State 49
 		ACTIONS => {
-			'IDENT' => 72
+			"<" => 64,
+			"[" => 63
 		}
 	},
 	{#State 50
-		DEFAULT => -46
+		DEFAULT => -44
 	},
 	{#State 51
 		ACTIONS => {
-			"(" => 73
+			'IDENT' => 66
+		},
+		GOTOS => {
+			'enumItems' => 67,
+			'enumItem' => 65
 		}
 	},
 	{#State 52
 		ACTIONS => {
-			"[" => 74,
-			"<" => 75
-		}
+			"[" => 69,
+			"<" => 68
+		},
+		DEFAULT => -50
 	},
 	{#State 53
-		DEFAULT => -37
+		ACTIONS => {
+			'IDENT' => 70
+		}
 	},
 	{#State 54
-		DEFAULT => -31
+		ACTIONS => {
+			"union" => 14,
+			"quadruple" => 20,
+			"int" => 19,
+			"string" => 17,
+			"bool" => 16,
+			"long" => 15,
+			"enum" => 24,
+			"double" => 25,
+			"opaque" => 23,
+			"unsigned" => 21,
+			"hyper" => 22,
+			"void" => 31,
+			"char" => 32,
+			"float" => 30,
+			"struct" => 29,
+			'IDENT' => 28,
+			"short" => 27
+		},
+		GOTOS => {
+			'declaration' => 72,
+			'structItem' => 71,
+			'structItems' => 73,
+			'typeSpecifier' => 26
+		}
 	},
 	{#State 55
-		DEFAULT => -35
+		DEFAULT => -45
 	},
 	{#State 56
-		DEFAULT => -39
+		ACTIONS => {
+			";" => 74
+		}
 	},
 	{#State 57
-		DEFAULT => -33
+		ACTIONS => {
+			";" => 75
+		}
 	},
 	{#State 58
 		ACTIONS => {
@@ -380,276 +380,277 @@ sub new {
 	},
 	{#State 61
 		ACTIONS => {
-			"=" => 79
+			'IDENT' => 28,
+			"void" => 31,
+			"char" => 32,
+			"float" => 30,
+			"struct" => 29,
+			"short" => 27,
+			"double" => 25,
+			"enum" => 24,
+			"unsigned" => 21,
+			"hyper" => 22,
+			"opaque" => 23,
+			"int" => 19,
+			"quadruple" => 20,
+			"long" => 15,
+			"bool" => 16,
+			"string" => 17,
+			"union" => 14
+		},
+		GOTOS => {
+			'typeSpecifier' => 26,
+			'declaration' => 79
 		}
 	},
 	{#State 62
 		ACTIONS => {
-			"}" => 80
+			">" => 80,
+			'CONST' => 82,
+			'IDENT' => 81
+		},
+		GOTOS => {
+			'value' => 83
 		}
 	},
 	{#State 63
 		ACTIONS => {
-			"," => 81
+			'IDENT' => 81,
+			'CONST' => 82
 		},
-		DEFAULT => -27
+		GOTOS => {
+			'value' => 84
+		}
 	},
 	{#State 64
-		DEFAULT => -10
-	},
-	{#State 65
 		ACTIONS => {
-			";" => 82
-		}
-	},
-	{#State 66
-		ACTIONS => {
-			"}" => 83
-		}
-	},
-	{#State 67
-		ACTIONS => {
-			"char" => 19,
-			"struct" => 20,
-			"void" => 21,
-			"hyper" => 23,
-			"enum" => 22,
-			"int" => 25,
-			"float" => 24,
-			"short" => 26,
-			"string" => 29,
-			"double" => 28,
-			"quadruple" => 30,
-			"union" => 32,
-			"bool" => 33,
-			"opaque" => 35,
-			"long" => 34,
-			'IDENT' => 37,
-			"unsigned" => 36
-		},
-		DEFAULT => -23,
-		GOTOS => {
-			'structItems' => 84,
-			'declaration' => 65,
-			'typeSpecifier' => 31,
-			'structItem' => 67
-		}
-	},
-	{#State 68
-		DEFAULT => -11
-	},
-	{#State 69
-		ACTIONS => {
-			'IDENT' => 87,
-			'CONST' => 86,
-			">" => 88
+			'IDENT' => 81,
+			">" => 86,
+			'CONST' => 82
 		},
 		GOTOS => {
 			'value' => 85
 		}
 	},
-	{#State 70
+	{#State 65
 		ACTIONS => {
-			'IDENT' => 87,
-			'CONST' => 86,
-			">" => 90
+			"," => 87
 		},
-		GOTOS => {
-			'value' => 89
+		DEFAULT => -27
+	},
+	{#State 66
+		ACTIONS => {
+			"=" => 88
 		}
 	},
-	{#State 71
+	{#State 67
 		ACTIONS => {
-			'CONST' => 86,
-			'IDENT' => 87
+			"}" => 89
+		}
+	},
+	{#State 68
+		ACTIONS => {
+			'CONST' => 82,
+			">" => 90,
+			'IDENT' => 81
 		},
 		GOTOS => {
 			'value' => 91
 		}
 	},
-	{#State 72
+	{#State 69
+		ACTIONS => {
+			'IDENT' => 81,
+			'CONST' => 82
+		},
+		GOTOS => {
+			'value' => 92
+		}
+	},
+	{#State 70
 		DEFAULT => -59
 	},
+	{#State 71
+		ACTIONS => {
+			"short" => 27,
+			"struct" => 29,
+			"float" => 30,
+			"char" => 32,
+			"void" => 31,
+			'IDENT' => 28,
+			"opaque" => 23,
+			"hyper" => 22,
+			"unsigned" => 21,
+			"double" => 25,
+			"enum" => 24,
+			"string" => 17,
+			"bool" => 16,
+			"long" => 15,
+			"int" => 19,
+			"quadruple" => 20,
+			"union" => 14
+		},
+		DEFAULT => -23,
+		GOTOS => {
+			'declaration' => 72,
+			'structItems' => 93,
+			'structItem' => 71,
+			'typeSpecifier' => 26
+		}
+	},
+	{#State 72
+		ACTIONS => {
+			";" => 94
+		}
+	},
 	{#State 73
 		ACTIONS => {
-			"bool" => 33,
-			"union" => 32,
-			"unsigned" => 36,
-			'IDENT' => 37,
-			"long" => 34,
-			"opaque" => 35,
-			"quadruple" => 30,
-			"string" => 29,
-			"double" => 28,
-			"short" => 26,
-			"float" => 24,
-			"int" => 25,
-			"struct" => 20,
-			"char" => 19,
-			"hyper" => 23,
-			"enum" => 22,
-			"void" => 21
-		},
-		GOTOS => {
-			'declaration' => 92,
-			'typeSpecifier' => 31
+			"}" => 95
 		}
 	},
 	{#State 74
-		ACTIONS => {
-			'CONST' => 86,
-			'IDENT' => 87
-		},
-		GOTOS => {
-			'value' => 93
-		}
+		DEFAULT => -11
 	},
 	{#State 75
-		ACTIONS => {
-			'IDENT' => 87,
-			">" => 94,
-			'CONST' => 86
-		},
-		GOTOS => {
-			'value' => 95
-		}
+		DEFAULT => -10
 	},
 	{#State 76
 		DEFAULT => -12
 	},
 	{#State 77
-		DEFAULT => -14
+		DEFAULT => -13
 	},
 	{#State 78
-		DEFAULT => -13
+		DEFAULT => -14
 	},
 	{#State 79
 		ACTIONS => {
-			'CONST' => 86,
-			'IDENT' => 87
-		},
-		GOTOS => {
-			'value' => 96
+			")" => 96
 		}
 	},
 	{#State 80
-		DEFAULT => -26
+		DEFAULT => -57
 	},
 	{#State 81
-		ACTIONS => {
-			'IDENT' => 61
-		},
-		GOTOS => {
-			'enumItems' => 97,
-			'enumItem' => 63
-		}
+		DEFAULT => -49
 	},
 	{#State 82
-		DEFAULT => -25
+		DEFAULT => -48
 	},
 	{#State 83
-		DEFAULT => -22
+		ACTIONS => {
+			">" => 97
+		}
 	},
 	{#State 84
-		DEFAULT => -24
+		ACTIONS => {
+			"]" => 98
+		}
 	},
 	{#State 85
 		ACTIONS => {
-			">" => 98
+			">" => 99
 		}
 	},
 	{#State 86
-		DEFAULT => -48
+		DEFAULT => -55
 	},
 	{#State 87
-		DEFAULT => -49
+		ACTIONS => {
+			'IDENT' => 66
+		},
+		GOTOS => {
+			'enumItems' => 100,
+			'enumItem' => 65
+		}
 	},
 	{#State 88
-		DEFAULT => -57
+		ACTIONS => {
+			'IDENT' => 81,
+			'CONST' => 82
+		},
+		GOTOS => {
+			'value' => 101
+		}
 	},
 	{#State 89
-		ACTIONS => {
-			">" => 99
-		}
+		DEFAULT => -26
 	},
 	{#State 90
 		DEFAULT => -52
 	},
 	{#State 91
 		ACTIONS => {
-			"]" => 100
+			">" => 102
 		}
 	},
 	{#State 92
 		ACTIONS => {
-			")" => 101
+			"]" => 103
 		}
 	},
 	{#State 93
-		ACTIONS => {
-			"]" => 102
-		}
+		DEFAULT => -24
 	},
 	{#State 94
-		DEFAULT => -55
+		DEFAULT => -25
 	},
 	{#State 95
-		ACTIONS => {
-			">" => 103
-		}
+		DEFAULT => -22
 	},
 	{#State 96
-		DEFAULT => -29
-	},
-	{#State 97
-		DEFAULT => -28
-	},
-	{#State 98
-		DEFAULT => -58
-	},
-	{#State 99
-		DEFAULT => -53
-	},
-	{#State 100
-		DEFAULT => -51
-	},
-	{#State 101
 		ACTIONS => {
 			"{" => 104
 		}
 	},
-	{#State 102
+	{#State 97
+		DEFAULT => -58
+	},
+	{#State 98
 		DEFAULT => -54
 	},
-	{#State 103
+	{#State 99
 		DEFAULT => -56
 	},
+	{#State 100
+		DEFAULT => -28
+	},
+	{#State 101
+		DEFAULT => -29
+	},
+	{#State 102
+		DEFAULT => -53
+	},
+	{#State 103
+		DEFAULT => -51
+	},
 	{#State 104
 		ACTIONS => {
-			"case" => 105
+			"case" => 108
 		},
 		GOTOS => {
-			'caseClauses' => 106,
-			'caseClause' => 108,
+			'caseClauses' => 105,
+			'caseClause' => 106,
 			'caseBody' => 107
 		}
 	},
 	{#State 105
-		ACTIONS => {
-			'IDENT' => 87,
-			'CONST' => 86
-		},
-		GOTOS => {
-			'value' => 109
-		}
-	},
-	{#State 106
 		ACTIONS => {
 			"default" => 110
 		},
 		DEFAULT => -16,
 		GOTOS => {
-			'defaultClause' => 111
+			'defaultClause' => 109
+		}
+	},
+	{#State 106
+		ACTIONS => {
+			"case" => 108
+		},
+		DEFAULT => -18,
+		GOTOS => {
+			'caseClauses' => 111,
+			'caseClause' => 106
 		}
 	},
 	{#State 107
@@ -659,81 +660,80 @@ sub new {
 	},
 	{#State 108
 		ACTIONS => {
-			"case" => 105
+			'CONST' => 82,
+			'IDENT' => 81
 		},
-		DEFAULT => -18,
 		GOTOS => {
-			'caseClauses' => 113,
-			'caseClause' => 108
+			'value' => 113
 		}
 	},
 	{#State 109
+		DEFAULT => -17
+	},
+	{#State 110
 		ACTIONS => {
 			":" => 114
 		}
 	},
-	{#State 110
-		ACTIONS => {
-			":" => 115
-		}
-	},
 	{#State 111
-		DEFAULT => -17
+		DEFAULT => -19
 	},
 	{#State 112
 		DEFAULT => -15
 	},
 	{#State 113
-		DEFAULT => -19
+		ACTIONS => {
+			":" => 115
+		}
 	},
 	{#State 114
 		ACTIONS => {
-			"short" => 26,
-			"float" => 24,
-			"int" => 25,
-			"struct" => 20,
-			"char" => 19,
-			"hyper" => 23,
-			"enum" => 22,
-			"void" => 21,
-			"union" => 32,
-			"bool" => 33,
-			"unsigned" => 36,
-			'IDENT' => 37,
-			"opaque" => 35,
-			"long" => 34,
-			"quadruple" => 30,
-			"string" => 29,
-			"double" => 28
+			"string" => 17,
+			"long" => 15,
+			"bool" => 16,
+			"int" => 19,
+			"quadruple" => 20,
+			"union" => 14,
+			"short" => 27,
+			"struct" => 29,
+			"float" => 30,
+			"void" => 31,
+			"char" => 32,
+			'IDENT' => 28,
+			"opaque" => 23,
+			"unsigned" => 21,
+			"hyper" => 22,
+			"double" => 25,
+			"enum" => 24
 		},
 		GOTOS => {
-			'typeSpecifier' => 31,
-			'declaration' => 116
+			'declaration' => 116,
+			'typeSpecifier' => 26
 		}
 	},
 	{#State 115
 		ACTIONS => {
-			"quadruple" => 30,
-			"string" => 29,
-			"double" => 28,
-			"unsigned" => 36,
-			'IDENT' => 37,
-			"long" => 34,
-			"opaque" => 35,
-			"union" => 32,
-			"bool" => 33,
-			"hyper" => 23,
-			"enum" => 22,
-			"void" => 21,
-			"struct" => 20,
-			"char" => 19,
-			"short" => 26,
-			"float" => 24,
-			"int" => 25
+			"string" => 17,
+			"bool" => 16,
+			"long" => 15,
+			"int" => 19,
+			"quadruple" => 20,
+			"union" => 14,
+			"short" => 27,
+			"struct" => 29,
+			"float" => 30,
+			"char" => 32,
+			"void" => 31,
+			'IDENT' => 28,
+			"opaque" => 23,
+			"hyper" => 22,
+			"unsigned" => 21,
+			"double" => 25,
+			"enum" => 24
 		},
 		GOTOS => {
-			'typeSpecifier' => 31,
-			'declaration' => 117
+			'declaration' => 117,
+			'typeSpecifier' => 26
 		}
 	},
 	{#State 116
@@ -747,10 +747,10 @@ sub new {
 		}
 	},
 	{#State 118
-		DEFAULT => -20
+		DEFAULT => -21
 	},
 	{#State 119
-		DEFAULT => -21
+		DEFAULT => -20
 	}
 ],
                                   yyrules  =>
@@ -1234,7 +1234,7 @@ sub
 #line 262 "xdr.yp"
 {
             +{ name => $_[3],
-               type => { spec => 'named', name => $_[1] },
+               type => $_[1],
                pointer => 1,
                comments => delete $_[1]->{comments},
                location => $_[1]->{location} } }
@@ -1385,7 +1385,7 @@ XDR::Parse - Creation of an AST of an XDR specification
 
 =head1 VERSION
 
-0.1.2
+0.1.3
 
 =head1 DESCRIPTION
 
